.mq_message {
	margin-bottom:0.8em;
}
#streambox {
	position:fixed;
	top:1em;
	right:1em;
}
#streambox-btns {
	float:right
}
#streambox-btn {
	font-size:80%;
	border-radius:3px;
	background-color:black;
}
a#mqdelete_btn, a:visited#mqdelete_btn {
	color:red;
}
a#mqclose_btn, a:visited#mqclose_btn {
	color:green;
}
.inbox {
	padding:1em;
	border-radius:0.5em;
	border:1px solid grey;
	background-color:white;
	margin-bottom:0.5em;
}
/* --------------------------------- Messages formating ------------------------------- */
.mq-label {
	display: inline;
	padding: 0.5em;
	font-size: 75%;
	font-weight: bold;
	line-height: 1;
	text-align: center;
	white-space: nowrap;
	vertical-align: baseline;
	border-radius: 0.5em;
}
.mq-default {
	background-color: darkslategrey;
	color:white;
}
.mq-important {
	background-color: firebrick;
	color: white;
}
.mq-ok {
	background-color: forestgreen;
	color:white;
}
.mq-warning {
	background-color: orangered;
	color:white;
}
.mq-info {
	background-color: royalblue;
	color:white;
}
.mq-debug {
	background-color: orange;
	color:black;
}
.mq-error {
	background-color: red;
	color:white;
}
.mq-created {
	background-color: darkcyan;
	color:white;
}
.mq-edited {
	background-color: dodgerblue;
	color:white;
}
.mq-deleted {
	background-color: gold;
	color:white;
}

/*
.admin-msg {
	background-color:firebrick !important;
}
.admin-msg a, .admin-msg a:visited {
	color:white !important;
}
.admin-msg a.btn, .admin-msg a.btn:visited, .staff-msg a.btn, .staff-msg a.btn:visited {
	background-color:white !important;
	color:black !important;
}
.staff-msg {
	background-color:orange !important;
}
.staff-msg a, .staff-msg a:visited {
	color:black !important;
}
*/